<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="96"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>DIR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[الملف1، الملف2،...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>استجابة خطأ مجهولة</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>استجابة خطأ مجهولة</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>استجابة خطأ مجهولة</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="204"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - عارض صور سهل وسريع

الحقوق محفوظة © 2013
مشروع لكسكيوت: https://lxqt.org

المؤلفون:
Hong Jen Yee (PCMan) ‏&lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Open File</source>
        <translation>افتح ملفا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>Image files (%1)</source>
        <translation>ملفات الصور (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Open directory</source>
        <translation>افتح دليلا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Save File</source>
        <translation>احفظ الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (يحمّل…) - عارض الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (فشل التحميل) - عارض الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="695"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2×%3) - عارض الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>[*]Image Viewer</source>
        <translation>[*]عارض الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1167"/>
        <source>Thumbnails</source>
        <translation>المصغّرات</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1217"/>
        <source>EXIF Data</source>
        <translation>بيانات EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;مسح</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="283"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="300"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation>Imgur</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation>ImageShack</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>ابدأ</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>أوقِف</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>أغلِق</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>عارض الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>&amp;الملفات المفتوحة حديثا</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>&amp;About</source>
        <translation>&amp;عن</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Annotations Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>&amp;Open…</source>
        <translation>ا&amp;فتح…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Reload File</source>
        <translation>أ&amp;عِد تحميل الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>&amp;Save</source>
        <translation>ا&amp;حفظ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Save &amp;As</source>
        <translation>احفظ &amp;كَ‍</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>&amp;Close</source>
        <translation>أ&amp;غلِق</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;قرّب</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Zoom &amp;Out</source>
        <translation>ب&amp;عّد</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>ا&amp;نسخ إلى الحافظة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Next File</source>
        <translation>الملف التالي</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Previous File</source>
        <translation>الملف السابق</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Original Size</source>
        <translation>المقاس الأصلي</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>&amp;Fit</source>
        <translation>لا&amp;ئِم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;دوّر مع عقارب الساعة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>دوّر عكس ع&amp;قارب الساعة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>P&amp;references</source>
        <translation>التف&amp;ضيلات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>&amp;Print</source>
        <translation>ا&amp;طبع</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>First File</source>
        <translation>الملف الأول</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Last File</source>
        <translation>الملف الأخير</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&amp;New Window</source>
        <translation>نافذة &amp;جديدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Flip &amp;Horizontally</source>
        <translation>اقلب أ&amp;فقيا</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Capture Screenshot</source>
        <translation>التقط لقطة للشاشة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>F&amp;ull Screen</source>
        <translation>ملء ال&amp;شاشة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Flip &amp;Vertically</source>
        <translation>اقلب رأ&amp;سيا</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>أل&amp;صِق من الحافظة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>&amp;Slide Show</source>
        <translation>عر&amp;ض شرائح</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Delete</source>
        <translation>ا&amp;حذف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Show Thumbnails</source>
        <translation>اعرض المصغّرات</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>File Properties</source>
        <translation>خصائص الملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Open &amp;Directory</source>
        <translation>افتح ال&amp;دليل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Upload</source>
        <translation>ارفع</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Upload the image</source>
        <translation>ارفع الصورة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Show EXIF Data</source>
        <translation>اعرض بيانات EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>No Tool</source>
        <translation>بدون أداة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Deselect all drawing tools</source>
        <translation>الغاء تحديد جميع أدوات الرسم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Draw Arrow</source>
        <translation>رسم سهم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>Draw an arrow</source>
        <translation>رسم سهم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw Rectangle</source>
        <translation>رسم مستطيل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="593"/>
        <source>Draw a hollow rectangle</source>
        <translation>رسم مستطيل مجوّف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw Circle</source>
        <translation>رسم دائرة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>Draw a hollow circle</source>
        <translation>رسم دائرة مجوّفة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw Number</source>
        <translation>رسم رقم</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Draw incrementing numbers</source>
        <translation>رسم أرقام متزايدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>&amp;Annotations Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Show Outline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="656"/>
        <source>Copy Pa&amp;th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>Copy path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Resize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;ملف</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Help</source>
        <translation>م&amp;ساعدة</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Go</source>
        <translation>تنقّل</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>&amp;View</source>
        <translation>من&amp;ظور</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Edit</source>
        <translation>ت&amp;حرير</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Toolbar</source>
        <translation>شريط الأدوات</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>التفضيلات</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>سمة الأيقونات:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>لون الخلفية العادي:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>لون الخلفية بوضع ملء الشاشة:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Maximum number of recent files:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="81"/>
        <source>Slide show interval (seconds):</source>
        <translation>فترة عرض الشرائح (بالثواني):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="95"/>
        <source>Show image outline by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="102"/>
        <source>Show annotations toolbar by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="110"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="129"/>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>عام</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>Error</source>
        <translation type="unfinished">خطأ</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>لقطة شاشة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>خُذ لقطة للشاشة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>منطقة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>كامل الشاشة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>النافذة الحالية فحسب</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>التقِط مساحة من الشاشة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>ضمّن مؤشّر الفأرة</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>التأخير:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>ضمّن عنوان النافذة وإطارها</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>الرفع</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
</context>
</TS>
